from .factorial import Factorial
from .fractional_factorial import FractionalFactorial
from .ccd import CentralCompositeDesign
from .bbd import BoxBehnkenDesign
from .regression import RegressionAnalysis